==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PModifier.h <==
// public final class soot.jimple.parser.node.X2PModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f04cd65a680200ac soot_jimple_parser_node_X2PModifier
// @dep_class 6e08cbf20e4f84b7 soot_jimple_parser_node_XPModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_XPModifier

#include "soot/jimple/parser/node/XPModifier.h"

#ifndef _JC_soot_jimple_parser_node_X2PModifier_H_
#define _JC_soot_jimple_parser_node_X2PModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PModifier$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PModifier$sub_refs	_jc_soot_jimple_parser_node_X2PModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs	_jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$refs	_jc_soot_jimple_parser_node_X2PModifier$refs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$nonrefs	_jc_soot_jimple_parser_node_X2PModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$object	_jc_soot_jimple_parser_node_X2PModifier$object;

typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vmethods	_jc_soot_jimple_parser_node_X2PModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vtable	_jc_soot_jimple_parser_node_X2PModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vtype	_jc_soot_jimple_parser_node_X2PModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
extern void _jc_soot_jimple_parser_node_X2PModifier$method$_init$34dd5f8425a31c7d(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
extern struct _jc_soot_jimple_parser_node_PModifier$object *_jc_soot_jimple_parser_node_X2PModifier$method$getPModifier$9227457b8d50715d(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
extern void _jc_soot_jimple_parser_node_X2PModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PModifier$method$setPModifier$9a75f113829ce3ce(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$getPModifier$9227457b8d50715d;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$setPModifier$9a75f113829ce3ce;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
	struct _jc_soot_jimple_parser_node_PModifier$object	*(*getPModifier$9227457b8d50715d)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPModifier$9a75f113829ce3ce)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPModifier$vmethods	soot_jimple_parser_node_XPModifier;
	_jc_soot_jimple_parser_node_X2PModifier$vmethods	soot_jimple_parser_node_X2PModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_PModifier$object	*__5fpModifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PModifier$refs {
    _jc_soot_jimple_parser_node_X2PModifier$sub_refs	soot_jimple_parser_node_X2PModifier;
    _jc_soot_jimple_parser_node_XPModifier$sub_refs	soot_jimple_parser_node_XPModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPModifier$sub_nonrefs	soot_jimple_parser_node_XPModifier;
    _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs	soot_jimple_parser_node_X2PModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PModifier$object {
	_jc_soot_jimple_parser_node_X2PModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PModifier$vtype _jc_soot_jimple_parser_node_X2PModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PModifier.h <==
// public final class soot.jimple.parser.node.X2PModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f04cd65a680200ac soot_jimple_parser_node_X2PModifier
// @dep_class 6e08cbf20e4f84b7 soot_jimple_parser_node_XPModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_XPModifier

#include "soot/jimple/parser/node/XPModifier.h"

#ifndef _JC_soot_jimple_parser_node_X2PModifier_H_
#define _JC_soot_jimple_parser_node_X2PModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PModifier$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PModifier$sub_refs	_jc_soot_jimple_parser_node_X2PModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs	_jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$refs	_jc_soot_jimple_parser_node_X2PModifier$refs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$nonrefs	_jc_soot_jimple_parser_node_X2PModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PModifier$object	_jc_soot_jimple_parser_node_X2PModifier$object;

typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vmethods	_jc_soot_jimple_parser_node_X2PModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vtable	_jc_soot_jimple_parser_node_X2PModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PModifier$vtype	_jc_soot_jimple_parser_node_X2PModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PModifier$method$_init$34dd5f8425a31c7d(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PModifier$object *_jc_soot_jimple_parser_node_X2PModifier$method$getPModifier$9227457b8d50715d(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PModifier$method$setPModifier$9a75f113829ce3ce(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$getPModifier$9227457b8d50715d;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$setPModifier$9a75f113829ce3ce;
extern _jc_method _jc_soot_jimple_parser_node_X2PModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PModifier$object	*(*getPModifier$9227457b8d50715d)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPModifier$9a75f113829ce3ce)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *, struct _jc_soot_jimple_parser_node_PModifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPModifier$vmethods	soot_jimple_parser_node_XPModifier;
	_jc_soot_jimple_parser_node_X2PModifier$vmethods	soot_jimple_parser_node_X2PModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_PModifier$object	*__5fpModifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PModifier$refs {
    _jc_soot_jimple_parser_node_X2PModifier$sub_refs	soot_jimple_parser_node_X2PModifier;
    _jc_soot_jimple_parser_node_XPModifier$sub_refs	soot_jimple_parser_node_XPModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPModifier$sub_nonrefs	soot_jimple_parser_node_XPModifier;
    _jc_soot_jimple_parser_node_X2PModifier$sub_nonrefs	soot_jimple_parser_node_X2PModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PModifier$object {
	_jc_soot_jimple_parser_node_X2PModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PModifier$vtype _jc_soot_jimple_parser_node_X2PModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PModifier_H_ */
